@@ -35,19 +35,21 @@ def python():
     ''',end='')
     print(p.python_build())
 
+import pickle
+
 def opensource(module='pyextension'):
     if module == 'pyextension':
         file = open('__init__.py')
         get = file.read()
         file.close()
         return get
-    elif module == 'about':
-        file = open('about.py')
+    elif module == 'password':
+        file = open('password.py')
         get = file.read()
         file.close()
         return get
-    elif module == 'turtle':
-        file = open('turtle.py')
+    elif module == 'math:
+        file = open('math.py')
         get = file.read()
         file.close()
         return get
@@ -56,6 +58,11 @@ def opensource(module='pyextension'):
         get = file.read()
         file.close()
         return get
+    elif module == 'word bank data':
+        file = open('word_bank/wordbank.dat.py', 'rb')
+        get = pickle.load(file)
+        file.close()
+        return get
     elif module == 'word':
         file = open('word.py')
         get = file.read()
