@@ -4,6 +4,11 @@ def opensource(module='tkextension'):
         get = file.read()
         file.close()
         return get
+    elif module == 'about':
+        file = open('about.py')
+        get = file.read()
+        file.close()
+        return get
     elif module == 'canvas':
         file = open('canvas.py')
         get = file.read()
@@ -19,6 +24,16 @@ def opensource(module='tkextension'):
         get = file.read()
         file.close()
         return get
+    elif module == 'tix':
+        file = open('tix.py')
+        get = file.read()
+        file.close()
+        return get
+    elif module == 'turtle' or module == 'turtledrawer':
+        file = open('tuterdrawer.py')
+        get = file.read()
+        file.close()
+        return get
     elif module == 'value':
         file = open('value.py')
         get = file.read()
